Package: ib
Type: Package
Title: Bias Correction via Iterative Bootstrap
Version: 0.2.1
Description: An implementation of the iterative bootstrap procedure of 
    Kuk (1995) <doi:10.1111/j.2517-6161.1995.tb02035.x> to correct the estimation bias of a fitted model object. This
    procedure has better bias correction properties than the 
    bootstrap bias correction technique.
Authors@R: c(
    person("Samuel", "Orso", email="Samuel.Orso@unige.ch", role=c("aut","cre")),
    person("Stéphane", "Guerrier", role="ctb"),
    person("Yuming", "Zhang", role="ctb")
    )
Maintainer: Samuel Orso <Samuel.Orso@unige.ch>
Depends: R (>= 4.0.0)
Imports: betareg, lme4, Formula, MASS, Matrix, methods, Rdpack (>=
        0.7), stats, utils, VGAM
Suggests: testthat (>= 3.0.0), knitr, nlraa, rmarkdown
License: GPL (>= 2)
Encoding: UTF-8
RdMacros: Rdpack
RoxygenNote: 7.3.2
URL: https://smac-group.github.io/ib/,
        https://github.com/SMAC-Group/ib/
BugReports: https://github.com/SMAC-Group/ib/issues/
Config/testthat/edition: 3
NeedsCompilation: no
Packaged: 2025-09-04 13:32:09 UTC; orsos
Author: Samuel Orso [aut, cre],
  Stéphane Guerrier [ctb],
  Yuming Zhang [ctb]
Repository: CRAN
Date/Publication: 2025-09-04 14:00:02 UTC
Built: R 4.6.0; ; 2026-04-26 08:06:46 UTC; unix
