# Generated by roxygen2: do not edit by hand

export(bootstrap)
export(getEst)
export(getExtra)
export(getIteration)
export(getObject)
export(ib)
export(ibControl)
export(simulation)
exportClasses(Ib)
exportClasses(IbBetareg)
exportClasses(IbGlm)
exportClasses(IbGlmer)
exportClasses(IbLm)
exportClasses(IbLmer)
exportClasses(IbNegbin)
exportClasses(IbNls)
exportClasses(IbVglm)
exportClasses(SummaryIb)
exportClasses(SummaryIbBetareg)
exportClasses(SummaryIbGlm)
exportClasses(SummaryIbGlmer)
exportClasses(SummaryIbLm)
exportClasses(SummaryIbLmer)
exportClasses(SummaryIbNegbin)
exportClasses(SummaryIbNls)
exportClasses(SummaryIbVglm)
exportMethods(coef)
exportMethods(effects)
exportMethods(fitted)
exportMethods(getEst)
exportMethods(getExtra)
exportMethods(getIteration)
exportMethods(getObject)
exportMethods(ib)
exportMethods(plot)
exportMethods(predict)
exportMethods(residuals)
exportMethods(show)
exportMethods(simulation)
exportMethods(summary)
exportMethods(vcov)
import(methods)
importFrom(Formula,Formula)
importFrom(Formula,as.Formula)
importFrom(MASS,gamma.shape)
importFrom(Matrix,determinant)
importFrom(Rdpack,reprompt)
importFrom(VGAM,Coef)
importFrom(VGAM,familyname)
importFrom(VGAM,has.intercept)
importFrom(VGAM,model.framevlm)
importFrom(VGAM,predictvglm)
importFrom(VGAM,summaryvglm)
importFrom(VGAM,vbacksub)
importFrom(VGAM,vchol)
importFrom(VGAM,vforsub)
importFrom(VGAM,vglm)
importFrom(betareg,betareg)
importFrom(lme4,getME)
importFrom(lme4,glmer)
importFrom(lme4,lmer)
importFrom(lme4,mkVarCorr)
importFrom(methods,.hasSlot)
importFrom(methods,`slot<-`)
importFrom(methods,className)
importFrom(methods,new)
importFrom(methods,setClass)
importFrom(methods,setClassUnion)
importFrom(methods,setOldClass)
importFrom(methods,show)
importFrom(methods,slot)
importFrom(stats,coef)
importFrom(stats,delete.response)
importFrom(stats,fitted)
importFrom(stats,getCall)
importFrom(stats,glm)
importFrom(stats,is.empty.model)
importFrom(stats,lm)
importFrom(stats,model.frame)
importFrom(stats,model.matrix)
importFrom(stats,model.offset)
importFrom(stats,model.weights)
importFrom(stats,predict)
importFrom(stats,predict.glm)
importFrom(stats,predict.lm)
importFrom(stats,rbeta)
importFrom(stats,rgamma)
importFrom(stats,rnbinom)
importFrom(stats,rnorm)
importFrom(stats,runif)
importFrom(stats,sigma)
importFrom(stats,simulate)
importFrom(stats,summary.glm)
importFrom(stats,summary.lm)
importFrom(stats,terms)
importFrom(stats,var)
importFrom(stats,weights)
importFrom(utils,getFromNamespace)
